%bcond_with multiuser

Summary:        A screen manager that supports multiple logins on one terminal
Name:           screen
Version:        4.9.0
Release:        5%{?dist}
License:        GPLv3+
URL:            http://www.gnu.org/software/screen
Source0:        https://ftp.gnu.org/gnu/screen/screen-%{version}.tar.gz
Source1:        screen.pam

# fix CVE-2023-24626, git commit e9ad41bf
Patch0001:      0001-fix-missing-signal-sending-permission-check-on-faile.patch

Patch3000:     	screen-4.3.1-libs.patch
Patch3001:    	screen-4.3.1-screenrc.patch
Patch3002:    	screen-E3.patch
Patch3003:     	screen-4.3.1-suppress_remap.patch
Patch3004:     	screen-4.3.1-crypt.patch
Patch3005:     	screen-4.9.0-braille.patch
Patch3006:    	screen-configure-c99.patch

BuildRequires: 	make gcc automake autoconf
BuildRequires:  ncurses-devel pam-devel libutempter-devel texinfo systemd
Requires(pre):  /usr/sbin/groupadd

%description
Screen is a full-screen window manager that multiplexes a physical terminal between several 
processes, typically interactive shells. It is useful for users who telnet into a machine or 
are connected via a dumb terminal, but want to use more than just one login.

%prep
%autosetup -p1

%build
./autogen.sh

%configure \
	--enable-pam \
	--enable-colors256 \
	--enable-rxvt_osc \
	--enable-use-locale \
	--enable-telnet \
	--with-pty-mode=0620 \
	--with-pty-group=$(getent group tty | cut -d : -f 3) \
	--with-sys-screenrc="%{_sysconfdir}/screenrc" \
	--with-socket-dir="%{_rundir}/screen"

# support braille
sed -i -e 's/.*#.*undef.*HAVE_BRAILLE.*/#define HAVE_BRAILLE 1/;' config.h
sed -i -e 's/\(\/usr\)\?\/local\/etc/\/etc/g;' doc/screen.{1,texinfo}

for i in doc/screen.texinfo; do
    iconv -f iso8859-1 -t utf-8 < $i > $i.utf8 && mv -f ${i}{.utf8,}
done

rm -f doc/screen.info*

%make_build

%install
%make_install
mv -f %{buildroot}%{_bindir}/screen{-%{version},}

mkdir -p %{buildroot}%{_sysconfdir}
install -m 0644 etc/etcscreenrc %{buildroot}%{_sysconfdir}/screenrc
cat etc/screenrc >> %{buildroot}%{_sysconfdir}/screenrc

mkdir -p %{buildroot}%{_sysconfdir}/pam.d
install -p -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pam.d/screen

mkdir -p %{buildroot}%{_rundir}/screen

# systemd recreates it at startup using tmpfs
mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/screen.conf
# screen needs directory in /run
%if %{with multiuser}
d %{_rundir}/screen 0755 root root
%else
d %{_rundir}/screen 0775 root screen
%endif
EOF

rm -f %{buildroot}%{_infodir}/dir

%pre
/usr/sbin/groupadd -g 84 -r -f screen
:

%files
%license COPYING
%doc README doc/FAQ doc/README.DOTSCREEN ChangeLog
%config(noreplace) %{_sysconfdir}/screenrc
%config(noreplace) %{_sysconfdir}/pam.d/screen
%{_tmpfilesdir}/screen.conf
%if %{with multiuser}
%attr(4755,root,root) %{_bindir}/screen
%attr(755,root,root) %{_rundir}/screen
%else
%attr(2755,root,screen) %{_bindir}/screen
%attr(775,root,screen) %{_rundir}/screen
%endif
%{_infodir}/screen.info*
%{_datadir}/screen
%{_mandir}/man1/screen.*

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.9.0-5
- Rebuilt for loongarch release

* Mon Mar 11 2024 Yi Lin <nilusyi@tencent.com> - 4.9.0-4
- fix CVE-2023-24626

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.9.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.9.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 12 2023 Wang Guodong <gordonwwang@tencent.com> - 4.9.0-1
- initial build
